# RABBIT_HOLE

rabbit hole è un pacchetto composto da ue librerie per l'ascolto e l'invio di messaggi su code rabbitmq

## Installazione

Per installare RabbitHole, è sufficiente eseguire il seguente comando:

```bash
pip install gh-rabbit-hole
```
